﻿using System;
using System.Web.UI;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WebEdition;

namespace RectangleEvents
{
    public partial class DrawRectangle : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
            {
                Map1.MapUnit = GeographyUnit.DecimalDegree;

                WorldMapKitWmsWebOverlay worldMapKitWmsWebOverlay = new WorldMapKitWmsWebOverlay("WorldMapKitOverlay");
                Map1.CustomOverlays.Add(worldMapKitWmsWebOverlay);

                // Create an InMemoryMarkerOverlay for blue markers, and add some marks.
                InMemoryMarkerOverlay blueMarkerOverlay = new InMemoryMarkerOverlay("BlueMarkers");
                blueMarkerOverlay.FeatureSource.InternalFeatures.Add(new Feature(1, 1));
                blueMarkerOverlay.FeatureSource.InternalFeatures.Add(new Feature(-20, 10));
                blueMarkerOverlay.FeatureSource.InternalFeatures.Add(new Feature(-40, 20));
                blueMarkerOverlay.FeatureSource.InternalFeatures.Add(new Feature(-60, 30));
                blueMarkerOverlay.FeatureSource.InternalFeatures.Add(new Feature(-80, 40));
                blueMarkerOverlay.FeatureSource.InternalFeatures.Add(new Feature(-100, 50));
                blueMarkerOverlay.FeatureSource.InternalFeatures.Add(new Feature(-120, 60));
                blueMarkerOverlay.ZoomLevelSet.ZoomLevel01.DefaultMarkerStyle.WebImage = new WebImage("/theme/default/img/marker_blue.gif", 21, 25, (float)-10.5, -25);
                blueMarkerOverlay.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                Map1.CustomOverlays.Add(blueMarkerOverlay);

                // Create an InMemoryMarkerOverlay for red markers.
                InMemoryMarkerOverlay redMarkerOverlay = new InMemoryMarkerOverlay("RedMarkers");
                redMarkerOverlay.ZoomLevelSet.ZoomLevel01.DefaultMarkerStyle.WebImage = new WebImage("/theme/default/img/marker.gif", 21, 25, (float)-10.5, -25);
                redMarkerOverlay.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                Map1.CustomOverlays.Add(redMarkerOverlay);

                Map1.CurrentExtent = new RectangleShape(-131.22, 55.05, -54.03, 16.91);
            }
        }

        protected void Map1_TrackShapeFinished(object sender, EventArgs e)
        {
            // Get the Overlayers.
            InMemoryMarkerOverlay blueMarkerOverlay = (InMemoryMarkerOverlay)Map1.CustomOverlays["BlueMarkers"];
            InMemoryMarkerOverlay redMarkerOverlay = (InMemoryMarkerOverlay)Map1.CustomOverlays["RedMarkers"];

            // Open the InMemoryMarkerOverlays.
            blueMarkerOverlay.FeatureSource.Open();
            redMarkerOverlay.FeatureSource.Open();

            // Get last drawing Rectangle.
            Feature targetFeature = Map1.EditOverlay.Features[Map1.EditOverlay.Features.Count - 1];
            // Get the features which inside the Rectangle.
            var selectedFeatures = blueMarkerOverlay.FeatureSource.GetFeaturesInsideBoundingBox(targetFeature.GetBoundingBox(), ReturningColumnsType.NoColumns);
            // We remove the selected feature from blue marker overlay, and add it to red marker overlay and shape layer.
            foreach (Feature selectedMarker in selectedFeatures)
            {
                blueMarkerOverlay.FeatureSource.InternalFeatures.Remove(selectedMarker);
                redMarkerOverlay.FeatureSource.InternalFeatures.Add(selectedMarker);
            }
        }

        protected void buttonDrawRectangle_Click(object sender, EventArgs e)
        {
            Map1.EditOverlay.TrackMode = TrackMode.Rectangle;
        }
    }
}